:where(.wp-block-term-description){
  box-sizing:border-box;
  margin-bottom:var(--wp--style--block-gap);
  margin-top:var(--wp--style--block-gap);
}

.wp-block-term-description p{
  margin-bottom:0;
  margin-top:0;
}