.wp-block-accordion-item.is-open>.wp-block-accordion-heading .wp-block-accordion-heading__toggle-icon{
  transform:rotate(45deg);
}
@media (prefers-reduced-motion:no-preference){
  .wp-block-accordion-item{
    transition:grid-template-rows .3s ease-out;
  }
  .wp-block-accordion-item>.wp-block-accordion-heading .wp-block-accordion-heading__toggle-icon{
    transition:transform .2s ease-in-out;
  }
}