.wp-block-freeform.block-library-rich-text__tinymce{
  height:auto;
}
.wp-block-freeform.block-library-rich-text__tinymce li,.wp-block-freeform.block-library-rich-text__tinymce p{
  line-height:1.8;
}
.wp-block-freeform.block-library-rich-text__tinymce ol,.wp-block-freeform.block-library-rich-text__tinymce ul{
  margin-right:0;
  padding-right:2.5em;
}
.wp-block-freeform.block-library-rich-text__tinymce blockquote{
  border-right:4px solid #000;
  box-shadow:inset 0 0 0 0 #ddd;
  margin:0;
  padding-right:1em;
}
.wp-block-freeform.block-library-rich-text__tinymce pre{
  color:#1e1e1e;
  font-family:Menlo,Consolas,monaco,monospace;
  font-size:15px;
  white-space:pre-wrap;
}
.wp-block-freeform.block-library-rich-text__tinymce>:first-child{
  margin-top:0;
}
.wp-block-freeform.block-library-rich-text__tinymce>:last-child{
  margin-bottom:0;
}
.wp-block-freeform.block-library-rich-text__tinymce.mce-edit-focus{
  outline:none;
}
.wp-block-freeform.block-library-rich-text__tinymce a{
  color:var(--wp-admin-theme-color);
}
.wp-block-freeform.block-library-rich-text__tinymce:focus a[data-mce-selected]{
  background:#e5f5fa;
  border-radius:2px;
  box-shadow:0 0 0 1px #e5f5fa;
  margin:0 -2px;
  padding:0 2px;
}
.wp-block-freeform.block-library-rich-text__tinymce code{
  background:#f0f0f0;
  border-radius:2px;
  color:#1e1e1e;
  font-family:Menlo,Consolas,monaco,monospace;
  font-size:14px;
  padding:2px;
}
.wp-block-freeform.block-library-rich-text__tinymce:focus code[data-mce-selected]{
  background:#ddd;
}
.wp-block-freeform.block-library-rich-text__tinymce .alignright{
  float:right;
  margin:.5em 0 .5em 1em;
}
.wp-block-freeform.block-library-rich-text__tinymce .alignleft{
  float:left;
  margin:.5em 1em .5em 0;
}
.wp-block-freeform.block-library-rich-text__tinymce .aligncenter{
  display:block;
  margin-left:auto;
  margin-right:auto;
}
.wp-block-freeform.block-library-rich-text__tinymce .wp-more-tag{
  background-image:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAADtgAAAAoBAMAAAA86gLBAAAAJFBMVEVMaXG7u7vBwcHDw8POzs68vLzGxsbMzMy+vr7AwMDQ0NDGxsYKLGzpAAAADHRSTlMA///zWf+/f///TMxNVGuqAAABwklEQVR4Ae3dMXLaQBTH4bfj8UCpx8hq0vgKvgFNemhT6Qo6gg6R+0ZahM2QLmyBJ99XWP9V5+o3jIUcLQEAAAAAAAAAAAAAAAAAAAAAAABQ8j0WL9lfTtlt18uNXAUA8O/KVtfa1tdcrOdSh9gCQAMlh1hMNbZZ1bsrsQWABsrhLRbz7z5in/32UbfUMUbkMQCAh5RfGYv82UdMdZ6HS2wjT2ILAI8r3XmM2B3WvM59vfO2xXYW2yYAENuPU8S+X/N67mKxzy225yaxBQCxLV392UdcvwV0jPVUj98ntkBWT7C7+9u2/V/vGtvXIWJ6/4rtbottWa6Ri0NUT/u72LYttrb97LHdvUXMxxrb8TO2W2TF1rYbbLG1bbGNjMi4+2Sbi1FsbbvNFlvbFtt5fDnE3d9sP1/XeIyV2Nr2U2/guZUuptNrH/dPI9eLB6SaAEBs6wPJf3/PNk9tYgsAYrv/8TFuzx/fvkFqGtrEFgDEdpcZUb7ejXy6ntrEFgDENvL6gsas4vbdyKt4DACI7TxElJv/Z7udpqFNbAFAbKduy2uU2trttM/x28UWAAAAAAAAAAAAAAAAAAAAAAAAAADgDyPwGmGTCZp7AAAAAElFTkSuQmCC);
  background-position:50%;
  background-repeat:no-repeat;
  background-size:1900px 20px;
  cursor:default;
  display:block;
  height:20px;
  margin:15px auto;
  outline:0;
  width:96%;
}
.wp-block-freeform.block-library-rich-text__tinymce img::selection{
  background-color:initial;
}
.wp-block-freeform.block-library-rich-text__tinymce div.mceTemp{
  -ms-user-select:element;
}
.wp-block-freeform.block-library-rich-text__tinymce dl.wp-caption{
  margin:0;
  max-width:100%;
}
.wp-block-freeform.block-library-rich-text__tinymce dl.wp-caption a,.wp-block-freeform.block-library-rich-text__tinymce dl.wp-caption img{
  display:block;
}
.wp-block-freeform.block-library-rich-text__tinymce dl.wp-caption,.wp-block-freeform.block-library-rich-text__tinymce dl.wp-caption *{
  -webkit-user-drag:none;
}
.wp-block-freeform.block-library-rich-text__tinymce dl.wp-caption .wp-caption-dd{
  margin:0;
  padding-top:.5em;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview{
  border:1px solid #0000;
  clear:both;
  margin-bottom:16px;
  position:relative;
  width:99.99%;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview iframe{
  background:#0000;
  display:block;
  max-width:100%;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview .mce-shim{
  bottom:0;
  left:0;
  position:absolute;
  right:0;
  top:0;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview[data-mce-selected="2"] .mce-shim{
  display:none;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview .loading-placeholder{
  border:1px dashed #ddd;
  padding:10px;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview .wpview-error{
  border:1px solid #ddd;
  margin:0;
  padding:1em 0;
  word-wrap:break-word;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview .wpview-error p{
  margin:0;
  text-align:center;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview[data-mce-selected] .loading-placeholder,.wp-block-freeform.block-library-rich-text__tinymce .wpview[data-mce-selected] .wpview-error{
  border-color:#0000;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview .dashicons{
  display:block;
  font-size:32px;
  height:32px;
  margin:0 auto;
  width:32px;
}
.wp-block-freeform.block-library-rich-text__tinymce .wpview.wpview-type-gallery:after{
  clear:both;
  content:"";
  display:table;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery img[data-mce-selected]:focus{
  outline:none;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery a{
  cursor:default;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery{
  line-height:1;
  margin:auto -6px;
  overflow-x:hidden;
  padding:6px 0;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery .gallery-item{
  box-sizing:border-box;
  float:right;
  margin:0;
  padding:6px;
  text-align:center;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery .gallery-caption,.wp-block-freeform.block-library-rich-text__tinymce .gallery .gallery-icon{
  margin:0;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery .gallery-caption{
  font-size:13px;
  margin:4px 0;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-1 .gallery-item{
  width:100%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-2 .gallery-item{
  width:50%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-3 .gallery-item{
  width:33.3333333333%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-4 .gallery-item{
  width:25%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-5 .gallery-item{
  width:20%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-6 .gallery-item{
  width:16.6666666667%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-7 .gallery-item{
  width:14.2857142857%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-8 .gallery-item{
  width:12.5%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery-columns-9 .gallery-item{
  width:11.1111111111%;
}
.wp-block-freeform.block-library-rich-text__tinymce .gallery img{
  border:none;
  height:auto;
  max-width:100%;
  padding:0;
}

div[data-type="core/freeform"]:before{
  border:1px solid #ddd;
  outline:1px solid #0000;
}
@media not (prefers-reduced-motion){
  div[data-type="core/freeform"]:before{
    transition:border-color .1s linear,box-shadow .1s linear;
  }
}
div[data-type="core/freeform"].is-selected:before{
  border-color:#1e1e1e;
}
div[data-type="core/freeform"] .block-editor-block-contextual-toolbar+div{
  margin-top:0;
  padding-top:0;
}
div[data-type="core/freeform"].is-selected .block-library-rich-text__tinymce:after{
  clear:both;
  content:"";
  display:table;
}

.mce-toolbar-grp .mce-btn.mce-active button,.mce-toolbar-grp .mce-btn.mce-active i,.mce-toolbar-grp .mce-btn.mce-active:hover button,.mce-toolbar-grp .mce-btn.mce-active:hover i{
  color:#1e1e1e;
}
.mce-toolbar-grp .mce-rtl .mce-flow-layout-item.mce-last{
  margin-left:0;
  margin-right:8px;
}
.mce-toolbar-grp .mce-btn i{
  font-style:normal;
}

.block-library-classic__toolbar{
  border:1px solid #ddd;
  border-bottom:none;
  border-radius:2px;
  display:none;
  margin:0 0 8px;
  padding:0;
  position:sticky;
  top:0;
  width:auto;
  z-index:31;
}
div[data-type="core/freeform"].is-selected .block-library-classic__toolbar{
  border-color:#1e1e1e;
  display:block;
}
.block-library-classic__toolbar .mce-tinymce{
  box-shadow:none;
}
@media (min-width:600px){
  .block-library-classic__toolbar{
    padding:0;
  }
}
.block-library-classic__toolbar:empty{
  background:#f5f5f5;
  border-bottom:1px solid #e2e4e7;
  display:block;
}
.block-library-classic__toolbar:empty:before{
  color:#555d66;
  content:attr(data-placeholder);
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:13px;
  line-height:37px;
  padding:14px;
}
.block-library-classic__toolbar div.mce-toolbar-grp{
  border-bottom:1px solid #1e1e1e;
}
.block-library-classic__toolbar .mce-menubar,.block-library-classic__toolbar .mce-menubar>div,.block-library-classic__toolbar .mce-tinymce-inline,.block-library-classic__toolbar .mce-tinymce-inline>div,.block-library-classic__toolbar div.mce-toolbar-grp,.block-library-classic__toolbar div.mce-toolbar-grp>div{
  height:auto !important;
  width:100% !important;
}
.block-library-classic__toolbar .mce-container-body.mce-abs-layout{
  overflow:visible;
}
.block-library-classic__toolbar .mce-menubar,.block-library-classic__toolbar div.mce-toolbar-grp{
  position:static;
}
.block-library-classic__toolbar .mce-toolbar-grp>div{
  padding:1px 3px;
}
.block-library-classic__toolbar .mce-toolbar-grp .mce-toolbar:not(:first-child){
  display:none;
}
.block-library-classic__toolbar.has-advanced-toolbar .mce-toolbar-grp .mce-toolbar{
  display:block;
}

.block-editor-freeform-modal .block-editor-freeform-modal__content .mce-edit-area iframe{
  height:50vh !important;
}
@media (min-width:960px){
  .block-editor-freeform-modal .block-editor-freeform-modal__content:not(.is-full-screen){
    height:9999rem;
  }
  .block-editor-freeform-modal .block-editor-freeform-modal__content .components-modal__header+div{
    height:100%;
  }
  .block-editor-freeform-modal .block-editor-freeform-modal__content .mce-tinymce{
    height:calc(100% - 52px);
  }
  .block-editor-freeform-modal .block-editor-freeform-modal__content .mce-container-body{
    display:flex;
    flex-direction:column;
    height:100%;
    min-width:50vw;
  }
  .block-editor-freeform-modal .block-editor-freeform-modal__content .mce-edit-area{
    display:flex;
    flex-direction:column;
    flex-grow:1;
  }
  .block-editor-freeform-modal .block-editor-freeform-modal__content .mce-edit-area iframe{
    flex-grow:1;
    height:10px !important;
  }
}
.block-editor-freeform-modal__actions{
  margin-top:16px;
}