.wp-block-read-more{
  display:block;
  width:fit-content;
}
.wp-block-read-more:where(:not([style*=text-decoration])){
  text-decoration:none;
}
.wp-block-read-more:where(:not([style*=text-decoration])):active,.wp-block-read-more:where(:not([style*=text-decoration])):focus{
  text-decoration:none;
}