.wp-block-categories ul{
  padding-right:2.5em;
}
.wp-block-categories ul ul{
  margin-top:6px;
}
[data-align=center] .wp-block-categories{
  text-align:center;
}

.wp-block-categories__indentation{
  padding-right:16px;
}