.wp-block-site-logo{
  box-sizing:border-box;
  line-height:0;
}
.wp-block-site-logo a{
  display:inline-block;
  line-height:0;
}
.wp-block-site-logo.is-default-size img{
  height:auto;
  width:120px;
}
.wp-block-site-logo img{
  height:auto;
  max-width:100%;
}
.wp-block-site-logo a,.wp-block-site-logo img{
  border-radius:inherit;
}
.wp-block-site-logo.aligncenter{
  margin-left:auto;
  margin-right:auto;
  text-align:center;
}

:root :where(.wp-block-site-logo.is-style-rounded){
  border-radius:9999px;
}