.wp-block-navigation .wp-block-page-list{
  align-items:var(--navigation-layout-align, initial);
  background-color:inherit;
  display:flex;
  flex-direction:var(--navigation-layout-direction, initial);
  flex-wrap:var(--navigation-layout-wrap, wrap);
  justify-content:var(--navigation-layout-justify, initial);
}
.wp-block-navigation .wp-block-navigation-item{
  background-color:inherit;
}

.wp-block-page-list{
  box-sizing:border-box;
}