@charset "UTF-8";

.wp-block-separator{
  border:none;
  border-top:2px solid;
}

:root :where(.wp-block-separator.is-style-dots){
  height:auto;
  line-height:1;
  text-align:center;
}
:root :where(.wp-block-separator.is-style-dots):before{
  color:currentColor;
  content:"···";
  font-family:serif;
  font-size:1.5em;
  letter-spacing:2em;
  padding-left:2em;
}

.wp-block-separator.is-style-dots{
  background:none !important;
  border:none !important;
}