.wp-block-embed.alignleft,.wp-block-embed.alignright,.wp-block[data-align=left]>[data-type="core/embed"],.wp-block[data-align=right]>[data-type="core/embed"]{
  max-width:360px;
  width:100%;
}
.wp-block-embed.alignleft .wp-block-embed__wrapper,.wp-block-embed.alignright .wp-block-embed__wrapper,.wp-block[data-align=left]>[data-type="core/embed"] .wp-block-embed__wrapper,.wp-block[data-align=right]>[data-type="core/embed"] .wp-block-embed__wrapper{
  min-width:280px;
}

.wp-block-cover .wp-block-embed{
  min-height:240px;
  min-width:320px;
}

.wp-block-embed{
  overflow-wrap:break-word;
}
.wp-block-embed :where(figcaption){
  margin-bottom:1em;
  margin-top:.5em;
}
.wp-block-embed iframe{
  max-width:100%;
}

.wp-block-embed__wrapper{
  position:relative;
}

.wp-embed-responsive .wp-has-aspect-ratio .wp-block-embed__wrapper:before{
  content:"";
  display:block;
  padding-top:50%;
}
.wp-embed-responsive .wp-has-aspect-ratio iframe{
  bottom:0;
  height:100%;
  left:0;
  position:absolute;
  right:0;
  top:0;
  width:100%;
}

.wp-embed-responsive .wp-embed-aspect-21-9 .wp-block-embed__wrapper:before{
  padding-top:42.85%;
}
.wp-embed-responsive .wp-embed-aspect-18-9 .wp-block-embed__wrapper:before{
  padding-top:50%;
}
.wp-embed-responsive .wp-embed-aspect-16-9 .wp-block-embed__wrapper:before{
  padding-top:56.25%;
}
.wp-embed-responsive .wp-embed-aspect-4-3 .wp-block-embed__wrapper:before{
  padding-top:75%;
}
.wp-embed-responsive .wp-embed-aspect-1-1 .wp-block-embed__wrapper:before{
  padding-top:100%;
}
.wp-embed-responsive .wp-embed-aspect-9-16 .wp-block-embed__wrapper:before{
  padding-top:177.77%;
}
.wp-embed-responsive .wp-embed-aspect-1-2 .wp-block-embed__wrapper:before{
  padding-top:200%;
}